@@ -49,3 +49,8 @@ pub mod conf {
         Ok(cfg)
     }
 }
+
+/// some values for commands etc.
+pub mod val {
+    pub const VERSION: &str = "1.0.3";
+}
